@@ -14,7 +14,7 @@ Var.Xbar<-ifelse(fpc==FALSE,st.dev^2/n,(1-(n/N))*(st.dev^2/n))
 m<-sqrt(Var.Xbar)*t.star
 CI<-c(xbar,xbar-m,xbar+m)
 }
-head<-paste(paste(as.character(conf*100),"%",sep=""),c("t Confidence Interval for Population Mean"))
+head<-paste(paste(as.character(conf*100),"%",sep=""),c("t Confidence interval for population mean"))
 ends<-c("Estimate",paste(as.character(c((1-conf)/2,1-((1-conf)/2))*100),"%",sep=""))
 res<-list(SE=sqrt(Var.Xbar),margin=m,ci=CI,ends=ends,head=head)
 class(res)<-"ci"
@@ -38,7 +38,7 @@ SD.xbar<-ifelse(fpc==FALSE,sigma/sqrt(n),sqrt((1-(n/N))* (sigma^2/n)))
 m<-SD.xbar*z.star
 CI<-c(xbar,xbar-m,xbar+m)
 }
-head<-paste(paste(as.character(conf*100),"%",sep=""),c("z Confidence Interval for Population Mean"))
+head<-paste(paste(as.character(conf*100),"%",sep=""),c("z Confidence interval for population mean"))
 ends<-c("Estimate",paste(as.character(c((1-conf)/2,1-((1-conf)/2))*100),"%",sep=""))
 res<-list(margin=m,ci=CI,head=head,ends=ends)
 class(res)<-"ci"
